@@ -1,7 +1,7 @@
 package Clone::Util;
 
 our $DATE = '2016-03-10'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,7 +10,7 @@ use warnings;
 use Function::Fallback::CoreOrPP qw(clone);
 
 use Exporter qw(import);
-our @EXPORT_OK = qw(modclone sclone);
+our @EXPORT_OK = qw(clone modclone sclone);
 
 sub modclone(&$;@) {
     my $code = shift;
@@ -52,7 +52,7 @@ Clone::Util - Utilities related to cloning
 
 =head1 VERSION
 
-This document describes version 0.02 of Clone::Util (from Perl distribution Clone-Util), released on 2016-03-10.
+This document describes version 0.03 of Clone::Util (from Perl distribution Clone-Util), released on 2016-03-10.
 
 =head1 SYNOPSIS
 
@@ -70,6 +70,12 @@ This document describes version 0.02 of Clone::Util (from Perl distribution Clon
 
 =head1 FUNCTIONS
 
+None of the functions are exported by default, but they are exportable.
+
+=head2 clone($data) => $cloned
+
+This is just re-exported L<Function::Fallback::CoreOrPP>'s C<clone()>.
+
 =head2 modclone(\&code, $data) => $clone
 
 Clone C<$data> and then run code. Code will be given the clone of data. For
@@ -111,7 +117,7 @@ feature.
 
 =head1 SEE ALSO
 
-L<Function::Fallback::CoreOrPP>'s C<clone()> is used for cloning.
+L<Function::Fallback::CoreOrPP>
 
 =head1 AUTHOR
 
